﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.XR.Interaction.Toolkit;

/// <summary>
/// Class that manages all the sockets in a construction of SocketPart objects
/// </summary>
public class SocketManager : MonoBehaviour
{
    // Finished prefab object to be spawned after connecting
    public GameObject finishedPrefab = null;
    // Finished transform object to be applied after connecting
    public Transform finishedPrefabTransform = null;
    // All SocketPart objects of the construction
    public Socket[] sockets;
    
    private void Update() 
    {
        List<XRBaseInteractable> interactables = new List<XRBaseInteractable>();

        // Check sockets
        foreach(Socket socket in sockets)
        {
            if(!socket.IsConnected)
                return;
            // The selected interactable in the socket - part of the wheel
            interactables.Add(socket.selectTarget);
        }
        // If all are connected correctly, destroys all parts and instantiates new object
        Connect(interactables);    
    }
    /// <summary>
    /// Destroys all parts and instantiates the new object with desired transform
    /// </summary>
    /// <param name="interactables">Parts to be destroyed</param>
    private void Connect(List<XRBaseInteractable> interactables)
    {
        foreach(XRBaseInteractable interactable in interactables)
            Destroy(interactable.gameObject);
            
        GameObject finishedObject = Instantiate(finishedPrefab, transform);
        finishedObject.transform.localEulerAngles = finishedPrefabTransform.rotation.eulerAngles;
    }
}
