﻿using UnityEngine;
using UnityEngine.XR.Interaction.Toolkit;

/// <summary>
/// Interactable object, but not grabbable. Spawns simple objects upon interacting
/// </summary>
public class Spawner : XRBaseInteractable
{
    // Prefab to be spawned
    public GameObject prefab = null;

    protected override void Awake()
    {
        base.Awake();
    }
    /// <summary>
    /// Called upon enabling the object
    /// </summary>
    protected override void OnEnable()
    {
        base.OnEnable();
        // Event to be called when this object is selected
        selectEntered.AddListener(SelectObject);
    }
    /// <summary>
    /// Called upon disabling the object
    /// </summary>
    protected override void OnDisable()
    {
        base.OnDisable();
        selectEntered.RemoveListener(SelectObject);
    }
    private GameObject CreateObject(Transform interactorTransform)
    {
        return Instantiate(prefab, interactorTransform.position, interactorTransform.rotation);
    }
    /// <summary>
    /// Instantiate and select new object into the interacting interactor
    /// </summary>
    private void SelectObject(SelectEnterEventArgs args)
    {
        // Instantiate
        GameObject prefabObject = CreateObject(args.interactor.transform);
        XRGrabInteractable grab = null;

        // Force select the new object into the interacting interactor
        if(prefabObject.TryGetComponent<XRGrabInteractable>(out grab))
            interactionManager.ForceSelect(args.interactor, grab);
    }
}
