﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

/// <summary>
/// Simple hittable object that reacts to bullets
/// Implements interface IHittable
/// </summary>
public class Target : MonoBehaviour, IHittable
{
    private new Rigidbody rigidbody = null;
    private void Awake() 
    {
        rigidbody = GetComponent<Rigidbody>();
    }
    /// <summary>
    /// React to being hit by an object
    /// Method from IHittable
    /// <param name="hitTransform">Transform of the object that hit the target</param>
    /// <param name="force">Force of the object's rigidbody</param>
    /// </summary>
    public void Hit(Transform hitTransform, float force)
    {
        if(rigidbody)
            rigidbody.AddForce(hitTransform.forward * force);
    }
}
